jansky = 1e-26  # Watt /sq M / Hz
G = 6.67e-11  # SI
G_cgs = 6.67e-8  # cgs
au = 149597870700.0  # m
au_cm = 14959787070000.0  # cm
au_pc = 206265.0  # pc
Msol_kg = 1.989e30  # kg
Msol_g = 1.989e33  # g
L_sol_cgs = 3.839e33
c = 299792458.0  # m/s
c_kms = c * 1e-3
m_proton_g = 1.6727e-24  # grams
mean_molecular_weight = 2.353
Z_sol = 0.0196  # solar metallicity
stef_boltz_cgs = 5.6704e-5
k_b_cgs = 1.3807e-16
seconds_per_year = 31556952.0
M_earth_kg = 5.972e24
M_jup_kg = 1.898e27
M_earth_g = 5.972e27
M_jup_g = 1.898e30
